<!-- UID: 20250106T120000.000Z-A000 -->
<!-- Schema: v1 -->

# Architecture State

Current architecture decisions snapshot.

## Categories

### Authentication
- **Library**: next-auth (ADR 20250106T120000.000Z-A000)
- **Strategy**: OAuth (ADR 20250106T120000.000Z-A000)

